﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Configuration;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.Net.Http;
using System.Web;

namespace WindowsFormsApplication1
{

    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }


        private void Form1_Load(object sender, EventArgs e)
        {
            var appSettings = ConfigurationManager.AppSettings;

            string acturl = appSettings["act"];

            textBoxURL.Text = acturl;

        }

        private async void buttonExec_Click(object sender, EventArgs e)
        {
            // 結果をクリア
            textBoxStatus.Text = "";
            textBoxBody.Text = "";

            // URL実行
            try
            {
                HttpResponseMessage response = new HttpResponseMessage();

                using (HttpClient client = new HttpClient())
                {

                    TimeSpan timeout = new TimeSpan(0, 5, 0);      // Timeout 5分
                    client.Timeout = timeout;

                    // HeaderにX-ACT-Authorizationを設定
                    client.DefaultRequestHeaders.Add("X-ACT-Authorization", textBoxHeaders.Text);

                    response = await client.GetAsync(textBoxURL.Text);
                }


                textBoxStatus.Text = response.StatusCode.ToString();
                textBoxBody.Text = await response.Content.ReadAsStringAsync();
            }
            catch (Exception ex)
            {
                textBoxStatus.Text = "NG";
                if (ex.InnerException != null)
                {
                    textBoxBody.Text = ex.Message.ToString() + Environment.NewLine + ex.InnerException.ToString();
                }
                else
                {
                    textBoxBody.Text = ex.Message.ToString();
                }
            }

        }

        private void buttonReset_Click(object sender, EventArgs e)
        {
            var appSettings = ConfigurationManager.AppSettings;

            string acturl = appSettings["act"];

            textBoxURL.Text = acturl;

        }

        private void buttonCreate_Click(object sender, EventArgs e)
        {
            // App.configからURLを取得
            var appSettings = ConfigurationManager.AppSettings;

            string acturl = appSettings["act"];

            textBoxURL.Text = acturl;

            // 必須パラメータ
            if (textBoxUserName.Text.Length == 0)
            {
                MessageBox.Show("必須パラメータの入力がありません。");
                return;
            }

            if (textBoxPassword.Text.Length == 0)
            {
                MessageBox.Show("必須パラメータの入力がありません。");
                return;
            }

            // UserNameとPasswordからヘッダー作成
            // 「ユーザー名:パスワード」をBASE64エンコードしたものを値として表示
            string base64str = textBoxUserName.Text + ":" + textBoxPassword.Text;
            byte[] bs = System.Text.Encoding.UTF8.GetBytes(base64str);
            textBoxHeaders.Text = Convert.ToBase64String(bs);


            // 左8文字を取得 (例: 00000001)
            textBoxURL.Text += "?NWID=" + comboBoxNWID.Text.Substring(0, 8);

            if (textBoxPointStart.Text.Length > 0)
            {
                textBoxURL.Text += "&Start=" + textBoxPointStart.Text;
            }
            else
            {
                MessageBox.Show("必須パラメータの入力がありません。");
                return;
            }
            if (textBoxPointAreaRange.Text.Length > 0)
            {
                textBoxURL.Text += "&AreaRange=" + textBoxPointAreaRange.Text;
            }
            else
            {
                MessageBox.Show("必須パラメータの入力がありません。");
                return;
            }

            textBoxURL.Text += "&PolygonLevel=" + comboBoxPolygonLevel.Text;
           

            // オプション
            // 計算方向
            if (radioButtonAreaDirection0.Checked != false)
            {
                textBoxURL.Text += "&AreaDirection=0";
            }
            else
            {
                textBoxURL.Text += "&AreaDirection=1";
            }

            // 計算方法
            if (radioButtonCalcKindTime.Checked != false)
            {
                textBoxURL.Text += "&CalcKind=0";
            }
            else
            {
                textBoxURL.Text += "&CalcKind=1";
            }

            // 高速道路
            if (comboBoxNWID.Text.Substring(0,8) == "00f00108")
            {
                // 旅客のとき
                if (radioButtonTransport0.Checked != false)
                {
                    textBoxURL.Text += "&Transport=0";
                }
                else if (radioButtonTransport1.Checked != false)
                {
                    textBoxURL.Text += "&Transport=1";
                }
                else
                {
                    textBoxURL.Text += "&Transport=2";
                }
            }
            else
            {
                // 旅客以外
                if (radioButtonUseHighway0.Checked != false)
                {
                    textBoxURL.Text += "&UseHighway=0";
                }
                else
                {
                    textBoxURL.Text += "&UseHighway=1";
                }
            }

            // 測地系
            if (radioButtonDatum0.Checked != false)
            {
                textBoxURL.Text += "&Datum=0";
            }
            else
            {
                textBoxURL.Text += "&Datum=1";
            }

        }

        private void linkLabelACT_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            System.Diagnostics.Process.Start("http://www.act-inc.co.jp");

        }
        private void linkLabelNWID_LinkClicked(object sender, LinkLabelLinkClickedEventArgs e)
        {
            System.Diagnostics.Process.Start("http://www.act-inc.jp/dl/doc/NWIDrule.pdf");

        }


    }
}
